@@ -65,7 +65,7 @@
       }
       model_terms
     },
-    error = function(x) { NULL }
+    error = function(x) NULL
   )
 }
 
@@ -97,9 +97,9 @@
     gregexpr(
       pattern = "\\[(.*)\\]",
       text = terms,
-      perl = T
+      perl = TRUE
     )
-  ))
+  ), use.names = FALSE)
 
   "[all]" %in% tags
 }
