@@ -42,7 +42,7 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
   model <- .safe(get(attr(object, "model.name"), envir = parent.frame()))
 
   if (is.null(model)) {
-    insight::format_warning(
+    insight::format_alert(
       "Can't access original model to compute variance-covariance matrix of predictions."
     )
     return(NULL)
@@ -50,6 +50,11 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
 
   model_frame <- insight::get_data(model, source = "frame")
 
+  # sanity check - could data be extracted from model frame?
+  if (is.null(model_frame)) {
+    model_frame <- .safe(insight::get_data(model, source = "environment"))
+  }
+
   # check random effect terms. We can't compute SE if data has
   # factors with only one level, however, if user conditions on
   # random effects and only conditions on one level, it is indeed
@@ -191,6 +196,15 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
         insight::check_if_installed("sandwich")
         robust_package <- "sandwich"
       }
+      # clubSandwich does not work for pscl models
+      if (robust_package == "clubSandwich" && inherits(model, c("zeroinfl", "hurdle", "zerotrunc"))) {
+        insight::format_alert(paste0(
+          "Can't compute robust standard errors for models of class `",
+          class(model)[1],
+          "` when `vcov.fun=\"vcovCR\". Please use `vcov.fun=\"vcovCL\"` from the {sandwich} package instead."
+        ))
+        return(NULL)
+      }
       # compute robust standard errors based on vcov
       if (robust_package == "sandwich") {
         vcov.fun <- get(vcov.fun, asNamespace("sandwich"))
@@ -200,6 +214,10 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
         vcm <- as.matrix(do.call(vcov.fun, c(list(obj = model, type = vcov.type), vcov.args)))
       }
     }
+    # for zero-inflated models, remove zero-inflation part from vcov
+    if (inherits(model, c("zeroinfl", "hurdle", "zerotrunc"))) {
+      vcm <- vcm[!startsWith(rownames(vcm), "zero_"), !startsWith(rownames(vcm), "zero_"), drop = FALSE]
+    }
   } else {
     # get variance-covariance-matrix, depending on model type
     vcm <- suppressMessages(insight::get_varcov(model, component = "conditional"))
